@@ -40,9 +40,8 @@ class INCIDENCEEDITOR_EXPORT IncidenceDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit IncidenceDialog(Akonadi::IncidenceChanger *changer = nullptr,
-                             QWidget *parent = nullptr, Qt::WindowFlags flags = 0);
-    ~IncidenceDialog();
+    explicit IncidenceDialog(Akonadi::IncidenceChanger *changer = nullptr, QWidget *parent = nullptr, Qt::WindowFlags flags = {});
+    ~IncidenceDialog() override;
 
     /**
      * Loads the @param item into the dialog.
@@ -80,7 +79,7 @@ public:
     */
     void setInitiallyDirty(bool initiallyDirty);
 
-    Akonadi::Item item() const;
+    Q_REQUIRED_RESULT Akonadi::Item item() const;
 
 Q_SIGNALS:
     /**
